powered by
This function calculates the Roemer's environmental variance.
stability.env_var(dataf, res_var, gen_var, env_var, rep_var, plotIt = TRUE)
the name of the data frame containing the data to analyze.
the response variable.
the genotypes variable.
the environments variable.
the replications variable.
a logical value specifying if plot should be drawn; default is TRUE
A numeric vector with environmental variances of genotypes.
Becker, H.C. and J. Leon. 1988. Stability analysis in plant breeding. Plant Breeding 101: 1-23.
# NOT RUN { data(exp_data) stability.env_var(exp_data,"yield","gen","env","rep") # }
Run the code above in your browser using DataLab