the name of the data frame containing the data to analyze.
res_var
the response variable.
gen_var
the genotypes variable.
env_var
the environments variable.
rep_var
the replications variable.
plotIt
a logical value specifying if plot should be drawn; default is TRUE
Value
Returns a data frame:
mean_all
the genotype's mean
mean_opt
the genotype's max yield value
mean_lim
the genotype's min yield value
sd
the genotype's standard deviation
hom
the genotype's coefficient of homeostaticity
References
Khangildin V.V., Shayakhmetov I.F., Mardamshin A.G. 1979. Homeostasis of crop components and prerequisites for creating a model of a spring wheat variety. In Genetic analysis of quantitative traits of plants, 5-39. Ufa. (In Russian)