Learn R Programming

agrostab (version 0.1.0)

stability.hue: Nonparametric stability analysis

Description

This function calculates the Nassar&Huehn's stability parameters.

Usage

stability.hue(dataf, res_var, gen_var, env_var, rep_var, alpha = 0.05,
  plotIt = TRUE)

Arguments

dataf

the name of the data frame containing the data to analyze.

res_var

the response variable.

gen_var

the genotypes variable.

env_var

the environments variable.

rep_var

the replications variable.

alpha

the significance level; default is 0.5

plotIt

a logical value specifying if plot should be drawn; default is TRUE

Value

Returns a list of two objects:

statistic

the data frame object of stability analysis results:

S1-value of genotype Z1-value of genotype S2-value of genotype Z2-value of genotype

scores

the data frame object of summary results:

Z1.sum sum of Z1 Z2.sum sum of Z2 chi.ind chi-squared for (choosen alpha level)/(number of genotypes) and one degree of freedom chi.sum chi-squared for choosen alpha level and number of genotypes degree of freedom

References

Nassar, R. and M. Huehn. 1987. Studies on estimation of phenotypic stability: Tests of significance for nonparametric measures of phenotypic stability. Biometrics 43: 45-53. doi: 10.2307/2531947

Examples

Run this code
# NOT RUN {
data(exp_data)
stability.hue(exp_data,"yield","gen","env","rep")
# }

Run the code above in your browser using DataLab