Learn R Programming

agrostab (version 0.1.0)

stability.kilch: Variance of specific adaptive ability

Description

This function calculates several stability parameters suggested by Kilchevsky & Khotyleva.

Usage

stability.kilch(dataf, res_var, gen_var, env_var, rep_var, plotIt = TRUE)

Arguments

dataf

the name of the data frame containing the data to analyze.

res_var

the response variable.

gen_var

the genotypes variable.

env_var

the environments variable.

rep_var

the replications variable.

plotIt

a logical value specifying if plot should be drawn; default is TRUE

Value

Returns a list of two objects:

ANOVA

the analysis of variance table

scores

the data frame object of stability analysis results:

mean mean value OAC common adaptive ability sigma_ge variance of GE interaction sigma_CAC variance of specific adaptive ability S_g relative stability

References

Kilchevsky A.V., Khotyleva L.V. 1989. Genotype and environment in plant breeding. - Minsk: Science and technology. (In Russian).

Examples

Run this code
# NOT RUN {
data(exp_data)
stability.kilch(exp_data,"yield","gen","env","rep")
# }

Run the code above in your browser using DataLab