powered by
This function calculates the Martynov's weighted homeostaticity index.
stability.mart(dataf, res_var, gen_var, env_var, rep_var, alpha = 0.05, plotIt = TRUE)
the name of the data frame containing the data to analyze.
the response variable.
the genotypes variable.
the environments variable.
the replications variable.
alpha level of LSD; default is 0.05.
a logical value specifying if plot should be drawn; default is TRUE
A numeric vector with weighted homeostaticity index of genotypes.
Martynov S.P. 1990. A Method for the Estimation of Crop Varieties Stability. Biom. J. 7: 887-893.
# NOT RUN { data(exp_data) stability.mart(exp_data,"yield","gen","env","rep") # }
Run the code above in your browser using DataLab