Learn R Programming

agrostab (version 0.1.0)

stability.shu: Stability variance

Description

This function calculates the Shukla's stability variance.

Usage

stability.shu(dataf, res_var, gen_var, env_var, rep_var, plotIt = TRUE)

Arguments

dataf

the name of the data frame containing the data to analyze.

res_var

the response variable.

gen_var

the genotypes variable.

env_var

the environments variable.

rep_var

the replications variable.

plotIt

a logical value specifying if plot should be drawn; default is TRUE

Value

Returns a list of two objects:

ANOVA

the analysis of variance table

scores

the data frame object of stability analysis results:

bi regression of genotype means on environmental means t_value t-values for gypothesis that bi=0 p_value p-values for gypothesis that bi=0 sigma Shukla's stability variance value pf_value p-values for gypothesis that sigmai=0

References

Shukla, G.K. 1972. Some statistical aspects of partitioning genotype-environmental components of variability. Heredity 29: 237-245. doi: 10.1038/hdy.1972.87

Examples

Run this code
# NOT RUN {
data(exp_data)
stability.shu(exp_data,"yield","gen","env","rep")
# }

Run the code above in your browser using DataLab