Learn R Programming

agrostab (version 0.1.0)

stability.tai: Tai's stability analysis

Description

This function calculates the Tai's stability parameters.

Usage

stability.tai(dataf, res_var, gen_var, env_var, rep_var, plotIt = TRUE)

Arguments

dataf

the name of the data frame containing the data to analyze.

res_var

the response variable.

gen_var

the genotypes variable.

env_var

the environments variable.

rep_var

the replications variable.

plotIt

a logical value specifying if plot should be drawn; default is TRUE

Value

Returns a list of two objects:

ANOVA

the analysis of variance table

scores

the data frame object of stability analysis results:

alpha regression of genotype means on environmental means t_value t-values for gypothesis that alpha=0 p_value p-values for gypothesis that alpha=0 lambda deviation from linear responses pf_value p-values for gypothesis that lambda=0

References

Tai, G.C.C. 1971. Genotypic stability analysis and application to potato regional trials. Crop Sci. 11: 184-190. doi:10.2135/cropsci1971.0011183X001100020006x

Examples

Run this code
# NOT RUN {
data(exp_data)
stability.tai(exp_data,"yield","gen","env","rep")
# }

Run the code above in your browser using DataLab