Learn R Programming

agrostab (version 0.1.0)

stability.wricke: Ecovalence

Description

This function calculates the Wricke's ecovalence.

Usage

stability.wricke(dataf, res_var, gen_var, env_var, rep_var,
  plotIt = TRUE)

Arguments

dataf

the name of the data frame containing the data to analyze.

res_var

the response variable.

gen_var

the genotypes variable.

env_var

the environments variable.

rep_var

the replications variable.

plotIt

a logical value specifying if plot should be drawn; default is TRUE

Value

A numeric vector with genotype's ecovalence.

References

Wricke, G., 1962. Tjber eine Methode zur Erfassung der okologischen Streubreite in Feldversuchen. Z. Pflanzenzuchtg. 47: 92-96.

Examples

Run this code
# NOT RUN {
data(exp_data)
stability.wricke(exp_data,"yield","gen","env","rep")
# }

Run the code above in your browser using DataLab