powered by
This function calculates several stability parameters suggested by Kilchevsky & Khotyleva.
stability.kilch(dataf, res_var, gen_var, env_var, rep_var, plotIt = TRUE)
the name of the data frame containing the data to analyze.
the response variable.
the genotypes variable.
the environments variable.
the replications variable.
a logical value specifying if plot should be drawn; default is TRUE
Returns a list of two objects:
the analysis of variance table
the data frame object of stability analysis results:
mean
OAC
sigma_ge
sigma_CAC
S_g
Kilchevsky A.V., Khotyleva L.V. 1989. Genotype and environment in plant breeding. - Minsk: Science and technology. (In Russian).
# NOT RUN { data(exp_data) stability.kilch(exp_data,"yield","gen","env","rep") # }
Run the code above in your browser using DataLab