the name of the data frame containing the data to analyze.
res_var
the response variable.
gen_var
the genotypes variable.
env_var
the environments variable.
rep_var
the replications variable.
plotIt
a logical value specifying if plot should be drawn; default is TRUE
Value
Returns a list of two objects:
ANOVA
the analysis of variance table
scores
the data frame object of stability analysis results:
bi regression of genotype means on environmental means
t_value t-values for gypothesis that bi=0
p_value p-values for gypothesis that bi=0
sigma Shukla's stability variance value
pf_value p-values for gypothesis that sigmai=0
References
Shukla, G.K. 1972. Some statistical aspects of partitioning genotype-environmental components of variability. Heredity 29: 237-245. doi: 10.1038/hdy.1972.87