powered by
This function calculates the Wricke's ecovalence.
stability.wricke(dataf, res_var, gen_var, env_var, rep_var, plotIt = TRUE)
the name of the data frame containing the data to analyze.
the response variable.
the genotypes variable.
the environments variable.
the replications variable.
a logical value specifying if plot should be drawn; default is TRUE
A numeric vector with genotype's ecovalence.
Wricke, G., 1962. Tjber eine Methode zur Erfassung der okologischen Streubreite in Feldversuchen. Z. Pflanzenzuchtg. 47: 92-96.
# NOT RUN { data(exp_data) stability.wricke(exp_data,"yield","gen","env","rep") # }
Run the code above in your browser using DataLab